==> Dressing_1.0.0.202510151010-1188.jar: src/dressing/model/MechanicDesignScriptManager.java <==
package dressing.model;

import org.eclipse.emf.ecore.util.EcoreUtil;

import groovy.lang.Binding;
import groovy.lang.GroovyShell;
import groovy.lang.Script;
import param.MechanicDesign;

public class MechanicDesignScriptManager {

	/**
	 * @param rootspace
	 * @param mechanicdesign
	 */
	public static void excuteStructureActions(DesignObject3D rootspace, MechanicDesign mechanicdesign) {
		if(!mechanicdesign.getStructureAction().isCreated()&& mechanicdesign.getStructureAction().getCreateAction()!=null && !mechanicdesign.getStructureAction().getCreateAction().isEmpty() ) {
			MechanicDesignScriptManager.createStructure(mechanicdesign);
		}else if(mechanicdesign.getStructureAction().getUpdateStructureAction()!=null && !mechanicdesign.getStructureAction().getUpdateStructureAction().isEmpty() ){
			MechanicDesignScriptManager.updateStructure(mechanicdesign,rootspace);
		}
	}
	
	public static void createStructure(MechanicDesign design) {

		Binding binding = new Binding();
		binding.setVariable("parent", design.getStructureAction().getContainer());
		binding.setVariable("structureAction", design.getStructureAction());
		binding.setVariable("deisgns", design.getStructureAction().getMechanicDesigns());
		binding.setVariable("EcoreUtil", EcoreUtil.class);
		binding.setVariable("List", java.util.List.class);
		binding.setVariable("ArrayList", java.util.ArrayList.class);
		binding.setVariable("MechanicDesign", param.MechanicDesign.class);

		GroovyShell shell = new GroovyShell(binding);
		try {
			Script script = shell.parse(design.getStructureAction().getCreateAction());
			Object ret = script.run();
			design.getStructureAction().setCreated(true);
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**
	 * execute the update script for the structure of the MechanicDesign
	 * 
	 * @param design
	 * @param rootspace2
	 */
	public static void updateStructure(MechanicDesign design, DesignObject3D rootspace2) {

		Binding binding = new Binding();
		binding.setVariable("parent", design.getStructureAction().getContainer());
		binding.setVariable("structureAction", design.getStructureAction());
		binding.setVariable("deisgns", design.getStructureAction().getMechanicDesigns());
		binding.setVariable("EcoreUtil", EcoreUtil.class);
		binding.setVariable("List", java.util.List.class);
		binding.setVariable("ArrayList", java.util.ArrayList.class);
		binding.setVariable("Space3D", dressing.model.Space3D.class);

		binding.setVariable("MechanicDesign", param.MechanicDesign.class);

		binding.setVariable("space", rootspace2);

		GroovyShell shell = new GroovyShell(binding);
		try {
			Script script = shell.parse(design.getStructureAction().getUpdateStructureAction());
			Object ret = script.run();
			design.getStructureAction().setCreated(true);
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
}

==> Dressing_1.0.0.202510281600-1189.jar: src/dressing/model/MechanicDesignScriptManager.java <==
package dressing.model;

import java.net.URLClassLoader;

import org.codehaus.groovy.control.CompilerConfiguration;
import org.codehaus.groovy.control.customizers.ImportCustomizer;
import org.eclipse.emf.ecore.util.EcoreUtil;

import groovy.lang.Binding;
import groovy.lang.GroovyShell;
import groovy.lang.Script;
import param.MechanicDesign;

public class MechanicDesignScriptManager {

	/**
	 * @param rootspace
	 * @param mechanicdesign
	 */
	public static void excuteStructureActions(DesignObject3D rootspace, MechanicDesign mechanicdesign) {
		if(!mechanicdesign.getStructureAction().isCreated()&& mechanicdesign.getStructureAction().getCreateAction()!=null && !mechanicdesign.getStructureAction().getCreateAction().isEmpty() ) {
			MechanicDesignScriptManager.createStructure(mechanicdesign);
		}else if(mechanicdesign.getStructureAction().getUpdateStructureAction()!=null && !mechanicdesign.getStructureAction().getUpdateStructureAction().isEmpty() ){
			MechanicDesignScriptManager.updateStructure(mechanicdesign,rootspace);
		}
	}
	
	public static void createStructure(MechanicDesign design) {

		Binding binding = new Binding();
		binding.setVariable("parent", design.getStructureAction().getContainer());
		binding.setVariable("structureAction", design.getStructureAction());
		binding.setVariable("deisgns", design.getStructureAction().getMechanicDesigns());
		binding.setVariable("EcoreUtil", EcoreUtil.class);
		binding.setVariable("List", java.util.List.class);
		binding.setVariable("ArrayList", java.util.ArrayList.class);
		binding.setVariable("MechanicDesign", param.MechanicDesign.class);

		GroovyShell shell = new GroovyShell(binding);
		try {
			Script script = shell.parse(design.getStructureAction().getCreateAction());
			Object ret = script.run();
			design.getStructureAction().setCreated(true);
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**
	 * execute the update script for the structure of the MechanicDesign
	 * 
	 * @param design
	 * @param rootspace2
	 */
	public static void updateStructure(MechanicDesign design, DesignObject3D rootspace2) {
		if (design == null || design.getStructureAction() == null) {
	        System.err.println("[updateStructure] MechanicDesign or StructureAction is null — aborting update.");
	        return;
	    }

	    String scriptText = design.getStructureAction().getUpdateStructureAction();
	    if (scriptText == null || scriptText.trim().isEmpty()) {
	        System.err.println("[updateStructure] No script found for updateStructureAction.");
	        return;
	    }
		Binding binding = new Binding();
		binding.setVariable("parent", design.getStructureAction().getContainer());
		binding.setVariable("structureAction", design.getStructureAction());
		binding.setVariable("deisgns", design.getStructureAction().getMechanicDesigns());
		binding.setVariable("EcoreUtil", EcoreUtil.class);
		binding.setVariable("List", java.util.List.class);
		binding.setVariable("ArrayList", java.util.ArrayList.class);
		binding.setVariable("Space3D", dressing.model.Space3D.class);

		binding.setVariable("param.MechanicDesign", param.MechanicDesign.class);
		binding.setVariable("param.PieceType", param.PieceType.class);

		binding.setVariable("space", rootspace2);

		GroovyShell shell = new GroovyShell(binding);
		try {
			Script script = shell.parse(scriptText);
			Object result = script.run();

			design.getStructureAction().setCreated(true);

			if (result != null) {
				System.out.println("[updateStructure] Script executed successfully. Result: " + result);
			} else {
				System.out.println("[updateStructure] Script executed successfully (no return value).");
			}
		} catch (Exception e) {
			System.err.println("[updateStructure] Script execution failed: " + e.getMessage());
			e.printStackTrace();
		}
	}
}
